@@ -122,7 +122,9 @@ class Registry(object):
                 if main_loop_type == MAIN_LOOP_GLIB:
                                 cache = AccessibleCache (app_name)
 
-		factory = AccessibleFactory(cache)
+                factory = AccessibleFactory(cache)
+
+                _os.environ["AT_SPI_CLIENT"] = "1"
 
                 # Set up the device event controllers
                 _connection = SyncAccessibilityBus ()
@@ -130,7 +132,7 @@ class Registry(object):
 
                 if app_name:
                         self.device_event_register = _NullDeviceEventRegister()
-                        seld.app_event_register    = _NullApplicationEventRegister()
+                        self.app_event_register    = _NullApplicationEventRegister()
 
 			name = _bus_object.GetNameOwner (app_name)
                         self.desktop = factory (name, _ATSPI_ROOT_PATH, _ATSPI_DESKTOP)
